
# Soul
A set of frontend tools for Magento 2

## How Do I Setup?
Luckily, it's super simple!
1. Make sure that you have this in your composer.json file - it will let you have access to download modules from the Pinpoint repo:
```
    "pinpoint": {
    	"type": "composer",
    	"url": "https://packages.pinpointdesigns.co.uk/"
    }
```
2. Make sure I'm in your composer file by running `composer require pinpoint/soul 0.1.0`. Make sure you're running at least PHP7.1 with composer and adjust as needed (i.e. `comp71 require pinpoint/soul`). Also, you'll see the version number in the `require`, please make sure you're getting the latest version that has been tagged [in the repository](https://github.com/PinpointDesigns/Soul/releases). 
**NOTE:** This will update any modules that are **not locked** to a version number. Please make sure that 3rd party modules have a fixed version number against them to avoid breaking anything else.
3. Once this has been grabbed and installed, you can go to `[site root]/vendor/pinpoint/soul` and run the command `npm install` to get all the dependencies.
4. Now you need to setup the tools, you can do this by typing `gulp setup`

## Per Site Configuration
Post setup, you'll now have a few files in `dev/tools/soul`

`browserslist.json`
This is where you can define which browsers that you're going to support via Autoprefixer in the style compilation flow. Out of the box, Soul will support [these browsers](https://browserl.ist/?q=%22%3E+0.5%25%22%2C%22Last+2+versions%22%2C%22Firefox+ESR%22%2C%22not+dead%22). If the client needs further support, you can use that website to work out which commands you need to extend that `browserslist.json` file to support further browsers.

`sass-lint.yml`
This file is the rules for the sass linter. It is there so that we all try to work to the same coding standards. This file contains those rules. You can find more information about them at [https://github.com/sasstools/sass-lint/tree/master/docs/rules](https://github.com/sasstools/sass-lint/tree/master/docs/rules). You shouldn't need to change these, but it's there if you want to see what standards to adhere to.

`themes.json`
This is where you tell me about your themes. You only need to tell me a few things about your themes:
```
{
	"base": {
		"src": "app/design/frontend/Pinpoint/Spirit",
		"dest": "pub/static/frontend/Pinpoint/Spirit",
		"locale": ["en_GB"]
	},
	"child": {
		"src": "app/design/frontend/Pinpoint/Child",
		"dest": "pub/static/frontend/Pinpoint/Child",
		"locale": ["en_GB"],
		"parent": "base"
	}
}
```
The first level in the `json` is the name of your theme.
`src` is where your theme will be - probably in `app/design/frontend`.
`dest` is where your theme will be going when compiled - usually `pub/static/frontend`.
`locale` is the language locales within Magento your theme will be compiled for.
`parent` is only used if it is a child theme.
## How Can I Help?
I am always in development, but currently I can build your styles and make sure you're using the correct coding standards. This is so any developer picking up the project will be instantly familiar with the layout and format of the Sass files.

Once the setup has been completed above, you will be able to navigate to `tools` and then form there you can run the toolset using the following commands.

`gulp styles`
This will run through all the inheritance for the themes within your site and compile the Sass in to a useable css file.

`gulp watch`
This will watch the Sass files for changes. When there is a change in one, the toolset will automatically compile the styles and update the built css files within the theme.

`gulp sasslint`
This will run the linter directly so you can see if there are any inconsistencies with the coding format.

## What's So Special?
During the `setup` of the tools I also create a symbolic link to `.git/hooks` which puts in place a git hook that will prevent you from committing code that doesn't adhere to the rules set out in the `sasslint` task.
